@@ -1,20 +1,20 @@
 """
 Helpers to load Django lazily when Django settings can't be configured.
 """
-
+from typing import Any, Tuple
 import os
 import sys
 
 import pytest
 
 
-def skip_if_no_django():
+def skip_if_no_django() -> None:
     """Raises a skip exception when no Django settings are available"""
     if not django_settings_is_configured():
         pytest.skip("no Django settings")
 
 
-def django_settings_is_configured():
+def django_settings_is_configured() -> bool:
     """Return whether the Django settings module has been configured.
 
     This uses either the DJANGO_SETTINGS_MODULE environment variable, or the
@@ -24,12 +24,13 @@ def django_settings_is_configured():
     ret = bool(os.environ.get("DJANGO_SETTINGS_MODULE"))
 
     if not ret and "django.conf" in sys.modules:
-        return sys.modules["django.conf"].settings.configured
+        django_conf = sys.modules["django.conf"]  # type: Any
+        return django_conf.settings.configured
 
     return ret
 
 
-def get_django_version():
+def get_django_version() -> Tuple[int, int, int, str, int]:
     import django
 
     return django.VERSION
